==> vue-components-1.5.13.tgz: package/lib/select/selectProps.rd.js <==
import { pt as e } from "@regiondev/vue-utils";
import "@vuelidate/validators";
import { sharedProps as t } from "../form/src/shared/validation/sharedProps.rd.js";
import "vue";
import { TriggerDefinition as r } from "../shared/types/types.rd.js";
const a = () => ({
  ...t(),
  modelValue: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  defaultValue: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  selectedItem: e.object,
  selectedItems: e.arrayOf(Object).def([]),
  simple: e.bool.def(!1),
  textKey: e.string.def("text"),
  idKey: e.string.def("id"),
  multiple: e.bool.def(!1),
  showFilter: e.bool.def(!1),
  hideSelected: e.bool.def(!1),
  maxTagCount: e.number,
  maxTagTextLength: e.number.def(10),
  loadingData: e.bool.def(!1),
  maxSelections: e.number,
  debounceMs: e.number.def(500),
  filterPlaceholder: e.string.def("Filter items`"),
  items: e.arrayOf(e.any),
  isGray: e.bool,
  filter: e.string.def(""),
  trigger: e.oneOf(r).def("click"),
  getPopupContainer: e.func.def(() => document.body),
  customRender: e.function
}), d = () => ({
  items: e.arrayOf(e.any),
  selected: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  multiple: e.bool.def(!1),
  loading: e.bool.def(!1),
  disabled: e.bool.def(!1),
  showFilter: e.bool.def(!1),
  trigger: e.oneOf(r).def("click"),
  getPopupContainer: e.func.def(() => document.body),
  textKey: e.string,
  idKey: e.string,
  filter: e.string.def(""),
  filterPlaceholder: e.string,
  hideSelected: e.bool
});
export {
  d as selectDropdownProps,
  a as selectProps
};

==> vue-components-1.5.16.tgz: package/lib/select/selectProps.rd.js <==
import { pt as e } from "@regiondev/vue-utils";
import "@vuelidate/validators";
import { sharedProps as t } from "../form/src/shared/validation/sharedProps.rd.js";
import "vue";
import { TriggerDefinition as r } from "../shared/types/types.rd.js";
const a = () => ({
  ...t(),
  modelValue: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  defaultValue: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  selectedItem: e.object,
  selectedItems: e.arrayOf(Object).def([]),
  simple: e.bool.def(!1),
  textKey: e.string.def("text"),
  idKey: e.string.def("id"),
  multiple: e.bool.def(!1),
  showFilter: e.bool.def(!1),
  hideSelected: e.bool.def(!1),
  maxTagCount: e.number,
  maxTagTextLength: e.number.def(10),
  loadingData: e.bool.def(!1),
  maxSelections: e.number,
  debounceMs: e.number.def(500),
  filterPlaceholder: e.string.def("Filter items`"),
  items: e.arrayOf(e.any),
  isGray: e.bool.def(!1),
  filter: e.string.def(""),
  trigger: e.oneOf(r).def("click"),
  getPopupContainer: e.func.def(() => document.body),
  customRender: e.function,
  containerClass: e.string
}), d = () => ({
  items: e.arrayOf(e.any),
  selected: e.oneOfType([e.string, e.number, e.arrayOf(String), e.arrayOf(Number)]),
  multiple: e.bool.def(!1),
  loading: e.bool.def(!1),
  disabled: e.bool.def(!1),
  showFilter: e.bool.def(!1),
  trigger: e.oneOf(r).def("click"),
  getPopupContainer: e.func.def(() => document.body),
  textKey: e.string,
  idKey: e.string,
  filter: e.string.def(""),
  filterPlaceholder: e.string,
  hideSelected: e.bool
});
export {
  d as selectDropdownProps,
  a as selectProps
};
